""" Singleton Module """
# pylint: disable=R0903


class Singleton(object):
    """A class that inherits the Singleton class will, after being instantiated,
    always return the first instance instead of a new one.
    This pattern can be used to deal with resources that are passed around, without having the code
    that uses them having to worry about the consequences of reinstantiating said class.
    Currently it is used in the APIAuth class, so that the access to the API can be passed around
    with having to reconnect or refresh.
    """

    _instance = None

    def __new__(cls, *args, **kwargs):
        if not cls._instance:
            try:
                cls._instance = super(Singleton, cls).__new__(cls, *args, **kwargs)
            except TypeError:
                cls._instance = super(Singleton, cls).__new__(cls)
        return cls._instance
