""" Provides a Console object that does not import YASARA itself, but rather asks for it as an
an instantiating argument. This allows it to be imported even if you are not sure if yasara is
actually available. """

# This object is used as part of a `with` statement and only requires non-public methods.
# pylint: disable=R0903


class Console(object):
    """This object can be used to safely enable the console with a code block, turning it off after
    the code block ends. Example:

    .. code-block:: python

        with Console(yasara):
            # Do stuff here...

        # Code continues without console.

    """

    def __init__(self, yasara):
        self.__yasara = yasara

    def __enter__(self):
        """Turns the console On."""
        self.__yasara.Console("On")

    def __exit__(self, _type, value, traceback):
        """Turns the console Off."""
        self.__yasara.Console("Off")
