# YASARA PLUGIN
# TOPIC:       YASARA 3DM Plugin Next Gen
# TITLE:       YASARA 3DM Plugin Next Gen
# AUTHOR:      Stephan Heijl, Bio-Prodict
# LICENSE:     Commercial
# DESCRIPTION: Provides an interface tot the users of Bio-Prodict 3DM
#
# This is a YASARA plugin to be placed in the /plg subdirectory
# Go to www.yasara.org/plugins for documentation and downloads

# YASARA menu entry
"""
MainMenu after Effects: 3DM
  PullDownMenu: Structures
    PopUpMenu: Load structure from 3DM
      Request: load_from_3dm
    PopUpMenu: Load model from 3DM
      Request: load_model_from_3dm
    PopUpMenu: Load corresponding compounds
      Request: load_corresponding_compounds
  PullDownMenu: Dataset
    PopUpMenu: Select a 3DM System
      Request: pick_system
    PopUpMenu: Select an alignment
      Request: pick_family
    PopUpMenu: Select a subset
      Request: pick_subset
    PopUpMenu: Select numbering scheme
      Request: renumber_objects
  PullDownMenu: Hotspot Baskets
    PopUpMenu: Load a Hotspot basket
      Request: load_hotspot_basket
    PopUpMenu: Create a new Hotspot basket
      Request: create_new_basket
    PopUpMenu: Delete a Hotspot basket
      Request: delete_hotspot_basket
    PopUpMenu: Remove an item from a basket
      Request: delete_basket_item
  PullDownMenu: Show superfamily data
    PopUpMenu: B-factor
      Request: show_superfamily_data_bvalue
    PopUpMenu: Conservation
      Request: show_superfamily_data_topconserved
    PopUpMenu: Correlations
      Request: show_superfamily_data_correlatedmutations
    PopUpMenu: Ligand contacts
      Request: show_superfamily_data_ligandcontacts
    PopUpMenu: Mutations
      Request: show_superfamily_data_mutations
    PopUpMenu: RMSD
      Request: show_superfamily_data_rmsd
    PopUpMenu: External protein-protein interactions
      Request: show_superfamily_data_pdbresiduecontactsexternal
    PopUpMenu: Intra-complex protein-protein interactions
      Request: show_superfamily_data_pdbresiduecontactsinternal
    PopUpMenu: DNA/RNA contacts
      Request: show_superfamily_data_dnarnacontacts
  PullDownMenu: Literature Hotspots
    PopUpMenu: Activity
      Request: show_literature_hotspots_kw_activity_increase
    PopUpMenu: Enantioselectivity
      Request: show_literature_hotspots_kw_enantioselectivity
    PopUpMenu: Specificity
      Request: show_literature_hotspots_kw_specificity
    PopUpMenu: Thermostability
      Request: show_literature_hotspots_kw_thermostability
    PopUpMenu: Custom keywords
      Request: show_literature_hotspots
  PullDownMenu: Color molecules by...
    PopUpMenu: Cores
      Request: color_molecules_by_cores
    PopUpMenu: Hydrophobicity
      Request: color_molecules_by_hydrophobicity
    PopUpMenu: Sidechain accessibility
      Request: color_molecules_by_accessibility
  PullDownMenu: Workspace reset
    Request: clear_scene
  PullDownMenu: Login with Bio-Prodict Scene
    Request: login_with_scene
  PullDownMenu: Set proxy information
    Request: set_proxy_information
  PullDownMenu: About 3DM
    PopUpMenu: About Bio-Prodict 3DM
      Request: show_about
    PopUpMenu: Go to 3DM YASARA Plugin Help
      Request: go_to_help_page
    PopUpMenu: Go to 3DM website
      Request: go_to_3dm_website

AtomContextMenu: 3DM
  PopUpMenu: Add residue to last loaded basket
    Request: add_residue_to_current_basket
  PopUpMenu: Add residue to a specific basket
    Request: add_residue_to_specific_basket
  PopUpMenu: Show amino acid distribution
    Request: show_amino_acid_distribution

ResidueContextMenu: 3DM
  PopUpMenu: Add residue to last loaded basket
    Request: add_residue_to_current_basket
  PopUpMenu: Add residue to a specific basket
    Request: add_residue_to_specific_basket
  PopUpMenu: Show amino acid distribution
    Request: show_amino_acid_distribution

SelectionContextMenu: 3DM
  PopUpMenu: Add residue to last loaded basket
    Request: add_residue_to_current_basket
  PopUpMenu: Add residue to a specific basket
    Request: add_residue_to_specific_basket
  PopUpMenu: Show amino acid distribution
    Request: show_amino_acid_distribution
"""

# Disabled F0401: Could not import module, because the yasara module is only really present in the
# yasara plg directory.
# Disabled W0703: Ideally we'd like to show any error to the user using a ShowMessage. Broad
# exception is therefore intended
# Disabled W0212: We access _run_yasara_request, which is explicitly protected against *users* to
# restrict the possibility of some kind of recursive calling nightmare inside YASARA
# Disabled C0431: The importing structure here is needed to ensure all the dependencies have loaded
# and the plugin is being run with correct support.
# pylint: disable=F0401,W0703,W0212

import os
import sys
import traceback

sys.path.insert(0, os.path.abspath("plugin/shared"))
from bioprodict.yasara.viewer.YasaraConsole import Console  # pylint: disable=C0413
from bioprodict.yasara.viewer.YasaraViewer import (
    YasaraViewer,
    yasara,
)  # pylint: disable=C0413
from bioprodict.shared.viewer.ErrorHandling import (
    ErrorHandling,
)  # pylint: disable=C0413

try:
    YV = YasaraViewer()
    YV._run_yasara_request(yasara.request)
except ImportError:
    yasara.ShowMessage("Could not import some dependencies. Try restarting the plugin.")
except Exception as ex:
    ERROR_HANDLED = ErrorHandling.handle(ex, YV, "YASARA", send=True)
    if issubclass(ERROR_HANDLED.__class__, Exception):

        yasara.ShowMessage(str(ex))
        TYPE, VALUE, TRACEBACK = sys.exc_info()
        with Console(yasara):
            TRACE = traceback.format_exception(TYPE, VALUE, TRACEBACK)
            # Replace Traceback with ReportedTraceback to avoid triggering a YASARA error.
            TRACE = [t.replace("Traceback", "ReportedTraceback") for t in TRACE]
            print("\n".join(TRACE))
    elif ERROR_HANDLED:
        yasara.ShowMessage("Error report sent to Bio-Prodict support.")
    else:
        yasara.ShowMessage("No report sent.")

if yasara.request == "Exit":
    yasara.Exit()
else:
    yasara.plugin.end()
